@@ -12,7 +12,7 @@ __docformat__ = "reStructureText"
 import toml
 import pathlib
 import time
-
+import os
 import geospacelab.toolbox.utilities.pylogging as mylog
 
 # datahub_data_root_dir = pathlib.Path("/Users/lcai/01-Work/00-Data/")
@@ -20,18 +20,25 @@ import geospacelab.toolbox.utilities.pylogging as mylog
 
 package_name = "geospacelab"
 
+on_rtd = os.environ.get('READTHEDOCS') == 'True'
+
 
 class Preferences(object):
+    _on_rtd = on_rtd
 
     def __init__(self):
         self.package_name = package_name
 
         self.user_config = {}
         self.set_user_config()
-        try:
-            self.datahub_data_root_dir = self.user_config['datahub']['data_root_dir']
-        except KeyError:
-            self.datahub_data_root_dir = None
+
+        if self._on_rtd:
+            self.datahub_data_root_dir = pathlib.Path.home() / 'Geospacelab' / 'Data'
+        else:
+            try:
+                self.datahub_data_root_dir = self.user_config['datahub']['data_root_dir']
+            except KeyError:
+                self.datahub_data_root_dir = None
 
     @property
     def datahub_data_root_dir(self):
@@ -63,9 +70,12 @@ class Preferences(object):
 
         if not self._datahub_data_root_dir.is_dir():
             mylog.simpleinfo.info(f"The direction ({self._datahub_data_root_dir}) does not exist!")
-            time.sleep(0.2)
-            result = input("Create it? [y]/n: ")
-            time.sleep(0.2)
+            if self._on_rtd:
+                result = 'y'
+            else:
+                time.sleep(0.2)
+                result = input("Create it? [y]/n: ")
+                time.sleep(0.2)
             if result.lower() in ['', 'y', 'yes']:
                 self._datahub_data_root_dir.mkdir(parents=True, exist_ok=False)
             elif result.lower() in ['n', 'no']:
