@@ -28,7 +28,7 @@ import numpy as np
 import geospacelab.toolbox.utilities.pylogging as mylog
 import geospacelab.toolbox.utilities.pybasic as pybasic
 import geospacelab.toolbox.utilities.pyclass as pyclass
-from geospacelab import preferences as pref
+from geospacelab.config import pref
 
 
 class DatasetBase(object):
@@ -262,7 +262,7 @@ class DatasetSourced(DatasetBase):
     def search_data_files(
             self,
             initial_file_dir=None, search_pattern='*', recursive=None,
-            direct_append=True, allow_multiple_files=False,
+            direct_append=True, allow_multiple_files=False, include_extension=True,
             **kwargs) -> list:
         """
         Search the data files by the input pattern in the file name. The search method is based on pathlib.glob.
@@ -288,11 +288,26 @@ class DatasetSourced(DatasetBase):
             initial_file_dir = self.data_root_dir
         if recursive is None:
             recursive = self.data_search_recursive
-        if str(self.data_file_ext):
-            search_pattern = search_pattern + '.' + self.data_file_ext
+
         if recursive:
             search_pattern = '**/' + search_pattern
-        paths = list(initial_file_dir.glob(search_pattern))
+
+        if include_extension and (self.data_file_ext not in ['*', '.*']):
+            if isinstance(self.data_file_ext, str):
+                exts = [self.data_file_ext]
+            elif isinstance(self.data_file_ext, (list, tuple)):
+                exts = self.data_file_ext
+            else:
+                raise TypeError
+            for i, ext in enumerate(exts):
+                if ext[0] != '.':
+                    exts[i] = '.' + ext
+            paths = [p.resolve() for p in initial_file_dir.glob(search_pattern) if p.suffix in exts]
+            #
+            # if str(self.data_file_ext):
+            #     search_pattern = search_pattern + '.' + self.data_file_ext
+        else:
+            paths = list(initial_file_dir.glob(search_pattern))
 
         import natsort
         paths = natsort.natsorted(paths, reverse=False)
@@ -361,6 +376,8 @@ class DatasetSourced(DatasetBase):
         """
         if load_mode is not None:
             self.load_mode = load_mode
+        if list(self.data_file_paths):
+            self.load_mode = 'assigned'
         if self.load_mode == 'AUTO':
             self.search_data_files(**kwargs)
         elif self.load_mode == 'dialog':
