@@ -28,22 +28,23 @@ class VisualAxis(object):
     """
 
     def __init__(self):
-        self.data = None
-        self.data_err = None
+        self.data = None # "@v.value"
+        self.data_err = None 
         self.data_scale = 1.
         self.data_res = None
         self.mask_gap = None
-        self.label = ''
+        self.label = None # "@v.label"
         self.label_style = 'double'  # or 'single
         self.label_pos = None  # label position
-        self.unit = ''
+        self.unit = '' 
         self.lim = None
         self.scale = 'linear'
         self.invert = False
         self.ticks = None
         self.tick_labels = None
         self.minor_ticks = None
-        self.major_tick_max = 6
+        self.major_tick_min = None
+        self.major_tick_max = None
         self.minor_tick_max = None
         self.reverse = False
         self.visible = True
@@ -72,7 +73,7 @@ class VisualPlotConfig(object):
         self.bar = {}
         self.scatter = {}
         self.fill_between = {}
-        self.style = None
+        self.style = None # "1E", "1P" or "1noE", "1S", "1B", "2P"
 
     def config(self, logging=True, **kwargs):
         pyclass.set_object_attributes(self, append=False, logging=logging, **kwargs)
@@ -237,7 +238,7 @@ class VariableBase(object):
     def __init__(
             self, value=None, error=None, data_type=None,
             name='', fullname='', label='', group='',
-            unit=None, unit_label=None, quantity=None,
+            unit='', unit_label=None, quantity=None,
             variable_type='scalar',
             ndim=None, depends=None, dataset=None, visual=None,
             **kwargs):
@@ -346,7 +347,8 @@ class VariableBase(object):
             if key in omit_attrs:
                 continue
             if key == 'visual':
-                kwargs['visual'] = self.visual.clone()
+                if self.visual is not None:
+                    kwargs['visual'] = self.visual.clone()
             elif key == 'dataset':
                 kwargs['dataset'] = self.dataset
             else:
@@ -593,17 +595,13 @@ class VariableBase(object):
     @property
     def unit_label(self):
         label = self._unit_label
-        if not str(label):
-            label = self.unit
-        return label
+        if label is None:
+            return self.unit
+        else:
+            return label
 
     @unit_label.setter
-    def unit_label(self, label):
-        if label is None:
-            self._unit_label = ''
-            return
-        if type(label) is not str:
-            raise TypeError
+    def unit_label(self, label: str or None):
         self._unit_label = label
 
     @property
