@@ -16,7 +16,7 @@ import functools
 import geospacelab.datahub as datahub
 from geospacelab.datahub import DatabaseModel, FacilityModel
 from geospacelab.datahub.sources.cdaweb import cdaweb_database
-from geospacelab import preferences as prf
+from geospacelab.config import prf
 import geospacelab.toolbox.utilities.pydatetime as dttool
 import geospacelab.toolbox.utilities.pybasic as basic
 import geospacelab.toolbox.utilities.pylogging as mylog
@@ -213,18 +213,20 @@ class Dataset(datahub.DatasetSourced):
         """
         Bz = kwargs['Bz']
         By = kwargs['By']
-        Bt = np.sqrt(By**2+Bz**2);
-        ca = np.sign(By) * (np.pi/2 - np.arcsin(Bz / Bt))
+        Bt = np.sqrt(By**2+Bz**2)
+        sign_By = np.sign(By)
+        sign_By[sign_By == 0] = 1.
+        ca = sign_By * (np.pi/2 - np.arcsin(Bz / Bt))
         ca = np.mod(ca, 2 * np.pi)
 
         if not to_radian:
             ca = ca / np.pi * 180
 
         var_name = 'CA_' + cs
-        var = self['B_x_GSM'].clone()
-        var.name = var_name
+        var = self.add_variable(var_name)
         var.value = ca.reshape(ca.size, 1)
         var.label = r'$\theta$'
+        var.unit = 'rad'
         self[var_name] = var
         return self[var_name]
 
@@ -236,18 +238,20 @@ class Dataset(datahub.DatasetSourced):
         """
         By = kwargs['By']
         Bx = kwargs['Bx']
-        Bt = np.sqrt(By**2+Bx**2);
-        az = np.sign(Bx) * (np.pi/2 - np.arcsin(By / Bt))
+        Bt = np.sqrt(By**2+Bx**2)
+        sign_Bx = np.sign(Bx)
+        sign_Bx[sign_Bx == 0] = 1.
+        az = sign_Bx * (np.pi/2 - np.arcsin(By / Bt))
         az = np.mod(az, 2 * np.pi)
 
         if not to_radian:
             az = az / np.pi * 180
 
         var_name = 'AZ_' + cs
-        var = self['B_x_GSM'].clone()
-        var.name = var_name
+        var = self.add_variable(var_name)
         var.value = az.reshape(az.size, 1)
         var.label = r'$\phi$'
+        var.unit = 'rad'
         self[var_name] = var
         return self[var_name]
 
@@ -259,18 +263,20 @@ class Dataset(datahub.DatasetSourced):
         """
         Bx = kwargs['Bx']
         Bz = kwargs['Bz']
-        Bt = np.sqrt(Bx ** 2 + Bz ** 2);
-        el = np.sign(Bz) * (np.pi / 2 - np.arcsin(Bx / Bt))
+        Bt = np.sqrt(Bx ** 2 + Bz ** 2)
+        sign_Bz = np.sign(Bz)
+        sign_Bz[sign_Bz == 0] = 1.
+        el = sign_Bz * (np.pi / 2 - np.arcsin(Bx / Bt))
         el = np.mod(el, 2 * np.pi)
 
         if not to_radian:
             el = el / np.pi * 180
 
         var_name = 'EL_' + cs
-        var = self['B_x_GSM'].clone()
-        var.name = var_name
+        var = self.add_variable(var_name)
         var.value = el.reshape(el.size, 1)
         var.label = r'$\alpha$'
+        var.unit = 'rad'
         self[var_name] = var
         return self[var_name]
 
@@ -288,14 +294,9 @@ class Dataset(datahub.DatasetSourced):
         BT = self['B_T_GSM'].value
         ncf = np.abs(v)**(4/3) * np.abs(BT)**(2/3) * np.abs(np.sin(ca*0.5))**(8/3)
 
-        var = self['CA_GSM'].clone()
-        var.value = ncf
-        var.name = 'NCF'
-        var.label = r'd$\Phi_{MP}/$d$t$'
-        var.unit = ''
-        var.unit_label = ''
-        var.visual.axis[1].lim = [None, None]
-        self['NCF'] = var
+        self['NCF'] = var_config.configured_variables['NCF'].clone()
+        self['NCF'].value = ncf
+
         return self['NCF']
 
     @property
