@@ -3,7 +3,7 @@ import datetime
 import geospacelab.datahub as datahub
 from geospacelab.datahub import DatabaseModel, FacilityModel, ProductModel
 from geospacelab.datahub.sources.madrigal import madrigal_database
-from geospacelab import preferences as prf
+from geospacelab.config import prf
 import geospacelab.toolbox.utilities.pydatetime as dttool
 import geospacelab.toolbox.utilities.pybasic as basic
 import geospacelab.toolbox.utilities.pylogging as mylog
