@@ -19,7 +19,7 @@ import bs4
 import os
 import pathlib
 
-from geospacelab import preferences as pfr
+from geospacelab.config import prf
 import geospacelab.datahub.sources.madrigal as madrigal
 import geospacelab.toolbox.utilities.pylogging as mylog
 import geospacelab.toolbox.utilities.pydatetime as dttool
@@ -59,7 +59,7 @@ class Downloader(object):
         self.dt_to = dt_to  # datetime to
 
         if data_file_root_dir is None:
-            self.data_file_root_dir = pfr.datahub_data_root_dir / 'Madrigal' / 'GNSS' / 'TEC'
+            self.data_file_root_dir = prf.datahub_data_root_dir / 'Madrigal' / 'GNSS' / 'TEC'
         else:
             self.data_file_root_dir = data_file_root_dir
         self.done = False
