@@ -23,7 +23,7 @@ import bs4
 import os
 import pathlib
 
-from geospacelab import preferences as pfr
+from geospacelab.config import pref as pfr
 import geospacelab.datahub.sources.madrigal as madrigal
 import geospacelab.toolbox.utilities.pylogging as mylog
 import geospacelab.toolbox.utilities.pydatetime as dttool
