@@ -15,7 +15,7 @@ from geospacelab.datahub.sources.madrigal.isr.millstonehill.basic.loader import
 from geospacelab.datahub.sources.madrigal.isr.millstonehill.downloader import Downloader as default_Downloader
 import geospacelab.datahub.sources.madrigal.isr.millstonehill.basic.variable_config as var_config
 from geospacelab.datahub.sources.madrigal import madrigal_database
-from geospacelab import preferences as prf
+from geospacelab.config import prf
 from geospacelab import datahub
 from geospacelab.datahub import SiteModel, DatabaseModel, FacilityModel
 import geospacelab.toolbox.utilities.pybasic as basic
@@ -188,26 +188,33 @@ class Dataset(datahub.DatasetSourced):
         condition = self['RESIDUAL'].value > residual_lim
         self.outlier_mask(condition)
 
-    def select_beams(self, field_aligned=False, az_el_pairs=None):
+    def select_beams(self, field_aligned=False, az_el_pairs=None, error_az=2, error_el=2):
         if field_aligned:
             if az_el_pairs is not None:
                 raise AttributeError("The parameters field_aligned and az_el_pairs cannot be set at the same time!")
             if self.site != 'UHF':
                 raise AttributeError("Only UHF can be applied.")
 
-        az = self['AZ'].value.flatten()
+        az = self['AZ'].value.flatten() % 360.
         el = self['EL'].value.flatten()
         if field_aligned:
-            inds = np.where(((np.abs(az - 188.6) <= 1.5) & (np.abs(el-77.7) <= 1.5)))[0]
+            inds = np.where(((np.abs(az - 188.6) <= error_az) & (np.abs(el-77.7) <= error_el)))[0]
             if not list(inds):
-                mylog.StreamLogger.info("No field-aligned beams found!")
-                return
+                mylog.StreamLogger.error("No field-aligned beams found!")
+                raise ValueError
+
         elif isinstance(az_el_pairs, list):
             inds = []
             for az1, el1 in az_el_pairs:
-                az1 = az1 % 360
-                inds.extend(np.where(((np.abs(az - az1) <= 0.5) & (np.abs(el-el1) <= 0.5)))[0])
-            inds.sort()
+                az1 = az1 % 360.
+                ind_1 = np.where(((np.abs(az - az1) <= error_az) & (np.abs(el-el1) <= error_el)))[0]
+                ind_2 = np.where(((np.abs(az - 360. - az1) <= error_az) & (np.abs(el-el1) <= error_el)))[0] 
+                ind_1 = np.append(ind_1, ind_2)
+                if not list(ind_1):
+                    mylog.StreamLogger.error("Cannot find the beam with az={:f} and el={:f}".format(az1, el1))
+                    raise ValueError
+                inds.extend(ind_1)
+            inds = np.sort(np.unique(np.array(inds))).tolist()
         else:
             raise ValueError
         self.time_filter_by_inds(inds)
