@@ -1,4 +1,4 @@
-from geospacelab import preferences
+from geospacelab.config import pref
 import geospacelab.datahub.sources.madrigal.utilities as utilities
 
 from geospacelab.datahub import DatabaseModel
@@ -22,9 +22,9 @@ The WDC Kyoto does not allow commercial applications of the geomagnetic indices.
 '''
 
 try:
-    default_user_email = preferences.user_config['datahub']['wdc']['user_email']
+    default_user_email = pref.user_config['datahub']['wdc']['user_email']
 except KeyError:
-    if preferences._on_rtd:
+    if pref._on_rtd:
         default_user_email = 'geospacelab@gmail.com'
         save = 'y'
     else:
@@ -32,8 +32,8 @@ except KeyError:
         default_user_email = input("User's email: ")
         save = input("Save as default? [y]/n: ")
     if save.lower() in ['', 'y', 'yes']:
-        uc = preferences.user_config
+        uc = pref.user_config
         uc.setdefault('datahub', {})
         uc['datahub'].setdefault('wdc', {})
         uc['datahub']['wdc']['user_email'] = default_user_email
-        preferences.set_user_config(user_config=uc, set_as_default=True)
+        pref.set_user_config(user_config=uc, set_as_default=True)
