@@ -20,8 +20,9 @@ class EISCATDashboard(TSDashboard):
         kwargs.setdefault('load_mode', 'AUTO')
 
         figure = kwargs.pop('figure', 'new')
-        figure_config = kwargs.pop('figure_config', {})
-        super().__init__(dt_fr=dt_fr, dt_to=dt_to, figure=figure, figure_config=figure_config)
+        figure_config = kwargs.pop('figure_config', {'figsize': (10, 10)})
+        timeline_extra_labels = kwargs.pop('timeline_extra_labels', None)
+        super().__init__(dt_fr=dt_fr, dt_to=dt_to, figure=figure, figure_config=figure_config, timeline_extra_labels=timeline_extra_labels)
         self.dock(datasource_contents=['madrigal', 'isr', 'eiscat'], **kwargs)
         self.host_dataset.load_data(load_mode=kwargs['load_mode'])
         # ds_1.list_all_variables()
@@ -38,8 +39,9 @@ class EISCATDashboard(TSDashboard):
     def outlier_mask(self, condition, fill_value=None):
         self.host_dataset.outlier_mask(condition, fill_value=fill_value)
 
-    def select_beams(self, field_aligned=False, az_el_pairs=None):
-        self.host_dataset.select_beams(field_aligned=field_aligned, az_el_pairs=az_el_pairs)
+    def select_beams(self, field_aligned=False, az_el_pairs=None, error_az=2., error_el=2.):
+        self.host_dataset.select_beams(field_aligned=field_aligned, az_el_pairs=az_el_pairs,
+                                       error_az=error_az, error_el=error_el)
 
     def list_eiscat_variables(self):
         self.host_dataset.list_all_variables()
@@ -114,15 +116,23 @@ class EISCATDashboard(TSDashboard):
             title = self.title
         super().add_title(x=x, y=y, title=title, append_time=append_time, **kwargs)
 
-    def quicklook(self):
+    def quicklook(self, time_res=None):
         n_e = self.assign_variable('n_e')
         T_i = self.assign_variable('T_i')
         T_e = self.assign_variable('T_e')
         v_i = self.assign_variable('v_i_los')
         az = self.assign_variable('AZ')
+        az.visual.axis[1].label = '@v.label'
+        az.visual.axis[1].unit = '@v.unit_label'
         el = self.assign_variable('EL')
+        el.visual.axis[1].label = '@v.label'
+        el.visual.axis[1].unit = '@v.unit_label'
         ptx = self.assign_variable('P_Tx')
+        ptx.visual.axis[1].label = '@v.label'
+        ptx.visual.axis[1].unit = '@v.unit_label'
         tsys = self.assign_variable('T_SYS_1')
+        tsys.visual.axis[1].label = '@v.label'
+        tsys.visual.axis[1].unit = '@v.unit_label'
         self.list_assigned_variables()
         self.list_datasets()
         self.check_beams()
@@ -133,7 +143,7 @@ class EISCATDashboard(TSDashboard):
         # dt_fr_1 = datetime.datetime.strptime('20201209' + '1300', '%Y%m%d%H%M')
         # dt_to_1 = datetime.datetime.strptime('20201210' + '1200', '%Y%m%d%H%M')
 
-        self.draw()
+        self.draw(time_res=time_res)
         self.add_title()
         self.add_panel_labels()
 
