@@ -5,14 +5,14 @@ import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib as mpl
 import pathlib
-import palettable
+# import palettable
 
 from matplotlib.gridspec import GridSpec, SubplotSpec
 from matplotlib.figure import Figure
 
 from cycler import cycler
 
-from geospacelab import preferences as pref
+from geospacelab.config import pref
 from geospacelab.toolbox.utilities.pyclass import StrBase
 import geospacelab.toolbox.utilities.pybasic as pybasic
 from geospacelab.visualization.mpl._helpers import check_panel_ax
@@ -28,8 +28,8 @@ except KeyError:
     pref.set_user_config(user_config=uc, set_as_default=True)
 
 
-plt.rcParams['font.serif'] = 'Ubuntu'
-plt.rcParams['font.monospace'] = 'Ubuntu Mono'
+# plt.rcParams['font.serif'] = 'Ubuntu'
+# plt.rcParams['font.monospace'] = 'Ubuntu Mono'
 plt.rcParams['font.size'] = 10
 plt.rcParams['axes.labelsize'] = 10
 plt.rcParams['axes.labelweight'] = 'book'
@@ -106,7 +106,7 @@ elif mpl_style == 'dark':
         (0.4627450980392157, 0.3058823529411765, 0.6235294117647059),
     ]
     default_cycler = (cycler(color=colors))
-    default_cycler = (cycler(color=palettable.cartocolors.qualitative.Safe_10.mpl_colors))
+    # default_cycler = (cycler(color=palettable.cartocolors.qualitative.Safe_10.mpl_colors))
     plt.rc('axes', prop_cycle=default_cycler)
 else:
     plt.style.use(mpl_style)
@@ -257,6 +257,15 @@ class DashboardBase(object):
         self.extra_axes = {}
         self.gs = None
 
+    def clear(self):
+        keys = list(self.panels.keys())
+        for ind_p in keys:
+            self.remove_panel(ind_p)
+        for ax in self.extra_axes.values():
+            ax.remove()
+        self.extra_axes = {}
+
+
     def set_layout(self, num_rows=None, num_cols=None, **kwargs):
         """
         Set the layout of the dashboard in a canvas using matplotlib GridSpec.
@@ -324,7 +333,7 @@ class DashboardBase(object):
         :type index: int or str.
         """
 
-        self.panels[index].remove()
+        self.panels[index].clear()
         del self.panels[index]
     #
     # def replace_panel(self, index, **kwargs):
@@ -356,22 +365,19 @@ class DashboardBase(object):
 
         self.add_text(x, y, title, **kwargs)
 
-    def add_panel_labels(self, panel_indices=None, style='alphabets', bbox_config=None, **kwargs):
+    def add_panel_labels(self, panel_indices=None, style='alphabets', bbox_config=None, labels=list(), **kwargs):
         if panel_indices is None:
             panel_indices = self.panels.keys()
+        default_bbox_config = {'facecolor': 'yellow', 'alpha': 0.3, 'edgecolor': 'none'}
 
         if style == 'alphabets':
             label_list = string.ascii_lowercase
         else:
             raise NotImplemented
 
-        if 'position' in kwargs.keys():
-            pos = kwargs['position']
-            x = pos[0]
-            y = pos[1]
-        else:
-            x = 0.02
-            y = 0.9
+        pos = kwargs.pop('position', [0.02, 0.9])
+        x = pos[0]
+        y = pos[1]
 
         kwargs.setdefault('ha', 'left')  # horizontal alignment
         kwargs.setdefault('va', 'center')  # vertical alignment
@@ -380,14 +386,21 @@ class DashboardBase(object):
         for ind, p_index in enumerate(panel_indices):
             panel = self.panels[p_index]
             pos_1 = panel.axes['major'].get_position()
-            if panel.label is None:
-                label = "({})".format(label_list[ind])
+            if list(labels) :
+                label = labels[ind]
+            elif panel.label is None:
+                label = "{}".format(label_list[ind])
             else:
                 label = panel.label
+                
+            label = "({})".format(label)
             kwargs.setdefault('fontsize', plt.rcParams['axes.labelsize'])
             kwargs.setdefault('fontweight', 'book')
             if bbox_config is None:
-                bbox_config = {'facecolor': 'yellow', 'alpha': 0.3, 'edgecolor': 'none'}
+                bbox_config = default_bbox_config
+            else:
+                default_bbox_config.update(**bbox_config)
+                bbox_config = default_bbox_config
             kwargs.setdefault('bbox', bbox_config)
             y_new = 1 - pos_0.height / pos_1.height + y * pos_0.height / pos_1.height
             panel.add_label(x, y_new, label, **kwargs)
@@ -509,6 +522,7 @@ class PanelBase(object):
         'twinx': 'off',
         'twinx_axes': [],
         'twiny_axes': [],
+        'shared': {},
         'lines': [],
         'collections': [],
         'legend': None,
@@ -562,6 +576,12 @@ class PanelBase(object):
         else:
             raise AttributeError
 
+    def clear(self):
+        for ax in self.axes.values():
+            ax.remove()
+
+        self.axes = {}
+
     def sca(self, ax):
         """
         Set current axes.
@@ -776,7 +796,6 @@ class PanelBase(object):
                 (pos_ax.y1 - pos_ax.y0) * cax_position[3],
             ]
             cax = self.add_axes(pos_cax)
-            cax_label_config = {'rotation': 270, 'va': 'bottom', 'size': 'medium'}
 
         icb = self.figure.colorbar(im, cax=cax, **kwargs)
 
@@ -805,6 +824,7 @@ class PanelBase(object):
                 cax.yaxis.set_minor_locator(minorlocator)
                 cax.yaxis.set_minor_formatter(mpl.ticker.NullFormatter())
         cax.yaxis.set_tick_params(labelsize='x-small')
+        return icb
 
     @property
     def major_ax(self):
