@@ -51,6 +51,7 @@ class TSDashboard(Dashboard):
             time_gap=True,
             timeline_major='UT',
             timeline_extra_labels=None,
+            timeline_same_format=False,
             **kwargs
     ):
         self.panel_layouts = []
@@ -60,6 +61,7 @@ class TSDashboard(Dashboard):
         figure_config = self._default_figure_config if figure_config is None else figure_config
         self.time_gap = time_gap
         self.timeline_major = timeline_major
+        self.timeline_same_format = timeline_same_format
         self.timeline_extra_labels = timeline_extra_labels
         kwargs.update(visual='on')
 
@@ -130,21 +132,25 @@ class TSDashboard(Dashboard):
                 panel_config.update(sharex=self.panels[0]())
             if ind == len(self._panels_configs.keys())-1:
                 bottom_panel = True
-                panel_config.update(timeline_extra_labels=self.timeline_extra_labels)
+                panel_config.update(timeline_extra_labels=self.timeline_extra_labels, timeline_same_format=self.timeline_same_format)
             else:
                 bottom_panel = False
             panel_config.update(bottom_panel=bottom_panel)
             self.add_panel(**panel_config)
 
-    def draw(self, dt_fr=None, dt_to=None, auto_grid=True):
+    def draw(self, dt_fr=None, dt_to=None, auto_grid=True, time_res=None):
         if dt_fr is not None:
             self._xlim[0] = dt_fr
         if dt_to is not None:
             self._xlim[1] = dt_to
 
+        if not isinstance(time_res,list):
+            time_res = [time_res] * len(self.panels.keys())
+
         npanel = 0
         for ind, panel in self.panels.items():
             panel._xlim = self._xlim
+            panel.time_res = time_res[ind]
             plot_layout = self.panel_layouts[npanel]
             plot_layout = self._validate_plot_layout(plot_layout)
             panel.draw(plot_layout)
@@ -359,11 +365,13 @@ class TSDashboard(Dashboard):
                     itpf = interp1d(x0, y0, bounds_error=False, fill_value='extrapolate')
                     y1 = itpf(x1)
             else:
-                y1 = y0[ind_1]
+                y1 = y0
             if type(value) in (int, float):
                 ind_1 = argrelmin(np.abs(y1 - value))
             elif type(value) is list:
                 ind_1 = np.where((y1 > value[0]) & (y1 < value[1]))[0]
+            else:
+                raise NotImplementedError
 
             x1 = x1[ind_1]
             y1 = y1[ind_1]
@@ -429,10 +437,9 @@ class TSDashboard(Dashboard):
             text_config.setdefault('clip_on', False)
             ax.text(x, y, label, transform=ax.transAxes, **text_config)
 
-    def add_top_bar(self, dt_fr, dt_to, bottom=0, top=0.02, **kwargs):
+    def add_top_bar(self, dt_fr, dt_to, bottom=0, top=0.02, facecolor='orange', **kwargs):
         bottom_extend = -1. - bottom
         top_extend = top
         kwargs.setdefault('alpha', 1.)
-        kwargs.setdefault('facecolor', 'orange')
-        self.add_shading(dt_fr, dt_to, bottom_extend=bottom_extend, top_extend=top_extend, **kwargs)
+        self.add_shading(dt_fr, dt_to, bottom_extend=bottom_extend, top_extend=top_extend, facecolor=facecolor, **kwargs)
 
