@@ -16,7 +16,9 @@ import matplotlib.pyplot as plt
 import matplotlib.colors as mpl_colors
 import matplotlib.ticker as mpl_ticker
 import matplotlib.dates as mpl_dates
+from matplotlib import rcParams
 from scipy.interpolate import interp1d
+from cycler import cycler
 
 from geospacelab.visualization.mpl.__base__ import PanelBase
 from geospacelab.datahub.__variable_base__ import VariableBase as VariableModel
@@ -61,7 +63,7 @@ class TSPanel(Panel):
             self, *args, 
             dt_fr=None, dt_to=None, figure=None, from_subplot=True,
             bottom_panel=True, timeline_reverse=False, timeline_extra_labels=None,
-            time_gap=True,
+            time_gap=True, time_res=None, timeline_same_format=False,
             **kwargs
     ):
         
@@ -72,7 +74,9 @@ class TSPanel(Panel):
 
         self._xlim = [dt_fr, dt_to]
         self.timeline_reverse = timeline_reverse
+        self.timeline_same_format=timeline_same_format
         self.time_gap = time_gap
+        self.time_res = time_res
         if timeline_extra_labels is None:
             timeline_extra_labels = []
         self.timeline_extra_labels = timeline_extra_labels
@@ -89,11 +93,15 @@ class TSPanel(Panel):
 
         if level == 0 and not list(layout_in):
             raise TypeError
-        elif level == 0:
+
+        if level == 0:
             if type(layout_in[0]) is list:
                 raise ValueError("The first element in the plot layout cannot be a list!")
             if any(type(i) is list for i in layout_in):
+                shared_cycler = cycler(color=plt.rcParams["axes.prop_cycle"])
                 self.axes_overview[ax]['twinx'] = 'on'
+                self.axes_overview[ax]['shared']['prop_cycle_iter'] = shared_cycler.__iter__()
+                ax.set_prop_cycle(color=[next(self.axes_overview[ax]['shared']['prop_cycle_iter'])['color']])
             if len(layout_in) == 1:
                 self.axes_overview[ax]['legend'] = 'off'
 
@@ -113,7 +121,10 @@ class TSPanel(Panel):
                     offset=50*(len(self.axes_overview[ax]['twinx_axes']))
                 )
                 self.axes_overview[ax_in]['twinx'] = 'self'
-                ax_in._get_lines.prop_cycler = ax._get_lines.prop_cycler
+                self.axes_overview[ax_in]['shared']['prop_cycle_iter'] = \
+                    self.axes_overview[ax]['shared']['prop_cycle_iter']
+                ax_in.set_prop_cycle(color=[next(self.axes_overview[ax_in]['shared']['prop_cycle_iter'])['color']])
+                # ax_in._get_lines.prop_cycler = ax._get_lines.prop_cycler
                 iplts_add = self.overlay_from_variables(elem, ax=ax_in, level=level+1)
             else:
                 raise NotImplementedError
@@ -185,8 +196,15 @@ class TSPanel(Panel):
 
         plot_config = basic.dict_set_default(kwargs, **var.visual.plot_config.line)
         plot_config = basic.dict_set_default(plot_config, **self._default_plot_config)
-        if self.axes_overview[ax]['twinx'] in ['on', 'self']:
+        # if self.axes_overview[ax]['twinx'] in ['on', 'self']:
+        #     if var.visual.axis[1].label is None:
+        #         var.visual.axis[1].label = '@v.label'
+        #     if var.visual.axis[1].unit is None:
+        #         var.visual.axis[1].unit = '@v.unit' 
+        if var.visual.axis[1].label is None:
             var.visual.axis[1].label = '@v.label'
+        if var.visual.axis[1].unit is None:
+            var.visual.axis[1].unit = '@v.unit_label'
         label = var.get_visual_axis_attr(axis=2, attr_name='label')
         plot_config = basic.dict_set_default(plot_config, label=label)
         if errorbar == 'off':
@@ -200,8 +218,8 @@ class TSPanel(Panel):
         self.axes_overview[ax]['lines'].extend(il)
         if self.axes_overview[ax]['legend'] is None:
             self.axes_overview[ax]['legend'] = 'on'
-        elif self.axes_overview[ax]['legend'] == 'off':
-            var.visual.axis[1].label = '@v.label'
+        # elif self.axes_overview[ax]['legend'] == 'off':
+        #    var.visual.axis[1].label = '@v.label'
         return il
 
     @check_panel_ax
@@ -247,7 +265,8 @@ class TSPanel(Panel):
                 x[:-1, :],
                 np.array(x[-1, 0] + delta_x[-1, 0] / 2).reshape((1, 1))
             ))
-
+        if len(y.shape) == 1:
+            y = y[np.newaxis, :]
         if y.shape[1] == z.shape[1]:
             delta_y = np.diff(y, axis=1)
             y[:, :-1] = y[:, :-1] + delta_y/2
@@ -311,8 +330,15 @@ class TSPanel(Panel):
         # use date locators
         # majorlocator, minorlocator, majorformatter = ticktool.set_timeline(self._xlim[0], self._xlim[1])
         from geospacelab.visualization.mpl.axis_ticks import DatetimeMajorFormatter, DatetimeMajorLocator, DatetimeMinorLocator
-        majorlocator = DatetimeMajorLocator()
-        majorformatter = DatetimeMajorFormatter(majorlocator)
+
+        maxticks = var_for_config.visual.axis[0].major_tick_max
+        if maxticks is None:
+            maxticks = 9
+        minticks = var_for_config.visual.axis[0].major_tick_min
+        if minticks is None:
+            minticks = 4
+        majorlocator = DatetimeMajorLocator(maxticks=maxticks, minticks=minticks)
+        majorformatter = DatetimeMajorFormatter(majorlocator, same_format=self.timeline_same_format)
 
         if not self.bottom_panel:
             majorformatter = mpl_ticker.NullFormatter()
@@ -345,7 +371,7 @@ class TSPanel(Panel):
 
         if self._default_xtick_params['extral_labels_y_offset'] is None:             
             figheight = self.figure.get_size_inches()[1]*2.54
-            yoffset = - 0.01 - 0.03 * 10/figheight * ax_pos.height
+            yoffset = - 0.013 - 0.031 * 10/figheight * ax_pos.height
         else:
             yoffset = self._default_xtick_params['extral_labels_y_offset']
         
@@ -415,7 +441,7 @@ class TSPanel(Panel):
                 ax.text(
                     xy_fig[ind_pos][0], xy_fig[ind_pos][1] + yoffset * ind - 0.013,
                     text,
-                    fontsize=plt.rcParams['xtick.labelsize'],
+                    fontsize=plt.rcParams['xtick.labelsize']-2,
                     horizontalalignment='center', verticalalignment='top',
                     transform=self.figure.transFigure
                 )
@@ -446,6 +472,9 @@ class TSPanel(Panel):
         self._set_ylim(ax=ax)
 
         # set y labels and alignment two methods: fig.align_ylabels(axs[:, 1]) or yaxis.set_label_coords
+        if self.axes_overview[ax]['twinx'] != 'off':
+            if var_for_config.visual.axis[1].label in ['@v.group', None]:
+                var_for_config.visual.axis[1].label = '@v.label'
         ylabel = var_for_config.get_visual_axis_attr('label', axis=1)
         yunit = var_for_config.get_visual_axis_attr('unit', axis=1)
         ylabel_style = var_for_config.get_visual_axis_attr('label_style', axis=1)
@@ -478,9 +507,10 @@ class TSPanel(Panel):
             else:
                 major_max = var_for_config.visual.axis[1].major_tick_max
                 if major_max is None:
-                    ax.yaxis.set_minor_locator(mpl_ticker.AutoLocator())
-                else:
-                    ax.yaxis.set_major_locator(mpl_ticker.MaxNLocator(major_max))
+                    # ax.yaxis.set_minor_locator(mpl_ticker.AutoLocator())
+                    major_max = 5
+
+                ax.yaxis.set_major_locator(mpl_ticker.MaxNLocator(major_max))
             minor_max = var_for_config.visual.axis[1].minor_tick_max
             if minor_max is None:
                 ax.yaxis.set_minor_locator(mpl_ticker.AutoMinorLocator())
@@ -546,9 +576,13 @@ class TSPanel(Panel):
             pax_ov = self.axes_overview[pax]
             if list(pax_ov['lines']):
                 il = pax_ov['lines'][0]
-                pax.yaxis.label.set_color(il.get_color())
-                pax.tick_params(axis='y', which='both', colors=il.get_color())
-                pax.spines['right'].set_edgecolor(il.get_color())
+                if isinstance(il, mpl.container.ErrorbarContainer):
+                    il_ = il[0]
+                else:
+                    il_ = il
+                pax.yaxis.label.set_color(il_.get_color())
+                pax.tick_params(axis='y', which='both', colors=il_.get_color())
+                pax.spines['right'].set_edgecolor(il_.get_color())
             else:
                 continue
 
@@ -575,7 +609,7 @@ class TSPanel(Panel):
             cax_position=cax_position
         )
 
-        self.add_colorbar(im, cax='new', **colorbar_config)
+        cb = self.add_colorbar(im, cax='new', **colorbar_config)
 
     def _retrieve_data_1d(self, var):
         x_data = var.get_visual_axis_attr(axis=0, attr_name='data')
@@ -611,7 +645,10 @@ class TSPanel(Panel):
         if y_err_data is None:
             y_err_data = var.error
 
-        x_data_res = var.visual.axis[0].data_res
+        if self.time_res is None:
+            x_data_res = var.visual.axis[0].data_res
+        else:
+            x_data_res = self.time_res
         x = x_data
         y = y_data * var.visual.axis[1].data_scale
         if y_err_data is None:
@@ -672,13 +709,18 @@ class TSPanel(Panel):
             raise ValueError
 
         z_data = z_data * var.visual.axis[2].data_scale
-        x_data_res = var.visual.axis[0].data_res
+        
+        if self.time_res is None:
+            x_data_res = var.visual.axis[0].data_res
+        else:
+            x_data_res = self.time_res
         time_gap = var.visual.axis[0].mask_gap
         if time_gap is None:
             time_gap = self.time_gap
         if time_gap:
-            x, y, z = arraytool.data_resample_2d(
-                x=x_data, y=y_data, z=z_data, xtype='datetime', xres=x_data_res, method='Null', axis=0)
+            # x, y, z = arraytool.data_resample_2d(
+            #     x=x_data, y=y_data, z=z_data, xtype='datetime', xres=x_data_res, method='Null', axis=0)
+            x, y, z = arraytool.regridding_2d_xgaps(x_data, y_data, z_data, xtype='datetime', xres=x_data_res)
         else:
             x = x_data
             y = y_data
@@ -699,7 +741,6 @@ class TSPanel(Panel):
                 raise NotImplementedError
         return label
 
-
 def check_panel_ax(func):
     def wrapper(*args, **kwargs):
         obj = args[-1]
